@@ -18,7 +18,7 @@ unless(defined($vid) && defined($pid)) {
 
 
 my $udev = Udev::FFI->new() or
-    die "Can't create udev context: $@.\n";
+    die "Can't create Udev::FFI object: $@.\n";
 
 my $enumerate = $udev->new_enumerate() or
     die "Can't create enumerate context: $@.\n";
