@@ -8,15 +8,13 @@ our (@ISA, @EXPORT_OK, %EXPORT_TAGS);
 require Exporter;
 @ISA = qw(Exporter);
 
+@EXPORT_OK = qw(major minor mkdev);
 
 %EXPORT_TAGS = (
-    'all' => [qw(major minor mkdev)]
+    'all' => \@EXPORT_OK
 );
 
 
-@EXPORT_OK = ( map {@{$_}} values %EXPORT_TAGS );
-
-
 
 sub major($) {
     $_[0]>>8; 
